What's changed?
--------------

1.6.0 (03/09/2021)
------------------
*   Now a user can specify the output generated (JSON or not) while creating the instances.
*   Removed junk and updated JSON structure.
*   Fix: Autocorrection was not working incase of incorrect spellings.

1.5.2 (25/08/2021)
------------------
*   Fixed errors arising due to too many redirects.

1.5.1 (20/08/2021)
------------------
*   Fixed error while pretty-printing of supported languages.
*   Fixed error: Couldn't find meanings (Due to change in source page structure).

1.4.2 (17/08/2021)
------------------
*   Added support for Translation into multiple languages.
*   Can query out list of supporting translation languages.
*   Fixed some bugs arising due to change in source page structure.

1.3.0 (01/08/2021)
------------------
*   Added new functions for searching Examples, Synonyms and Antonyms.

1.1.2 (31/07/2021)
------------------
*   Fixed some typo errors in code.

1.1.0 (30/07/2021)
------------------
*   Minor changes in code logic.

1.0.1 (29/07/2021)
------------------
*   First stable build with MeaningsFinder class for finding definations.
